@@ -60,7 +60,8 @@ def fuckStar():
     print('\n日卫星失败，请重新尝试')
     
 def lifeGame():
-    import f61d.lifeGame
+    from f61d.lifeGame import game
+    game()
     
 def func3():
     print('func3')
